PRISM Documentation — prism documentation

# PRISM Documentation

Methylation Pattern-based, Reference-free Inference of Subclonal Makeup

Contents:

- PRISM package
  - Submodules
    - prism.annotate module
    - prism.deconvolute module
    - prism.extract module
    - prism.hmm module
    - prism.mixture module
    - prism.preprocess module
    - prism.proofreading module
    - prism.scatter module
    - prism.util module

# Indices and tables

- Index
- Module Index
- Search Page